import {
  CORRELATION_RULES,
  CORRELATION_RULES_CREATE,
  useTranslation,
} from 'core/i18n';
import {
  CorrelationRulesDashboardLocale,
  TUseCorrelationRulesAddMessages,
} from './types';

export const useCorrelationRulesDashboardLocale =
  (): CorrelationRulesDashboardLocale => {
    const { t } = useTranslation([CORRELATION_RULES]);

    return {
      add: t('correlation_rules:app.correlation_rules.add_rules'),
      tableMessages: {
        sid: t('correlation_rules:app.correlation_rules.table.rule.sid'),
        rev: t('correlation_rules:app.correlation_rules.table.rule.rev'),
        name: t('correlation_rules:app.correlation_rules.table.rule.name'),
        status: t('correlation_rules:app.correlation_rules.table.rule.status'),
        group: t('correlation_rules:app.correlation_rules.table.rule.group'),
        created: t(
          'correlation_rules:app.correlation_rules.table.rule.created',
        ),
        updated: t(
          'correlation_rules:app.correlation_rules.table.rule.updated',
        ),
        actions: t(
          'correlation_rules:app.correlation_rules.table.rule.actions',
        ),
      },
      deletionConfirmation: t(
        'correlation_rules:app.correlation_rules.confirmation.rule_deletion',
      ),
      importConfirmation: t(
        'correlation_rules:app.correlation_rules.notification.import.confirmation.title',
      ),
      importPopover: t(
        'correlation_rules:app.correlation_rules.notification.import.popover.title',
      ),
      importSuccessTitle: t(
        'correlation_rules:app.correlation_rules.notification.import.success.title',
      ),
      importSuccessSubtitle: t(
        'correlation_rules:app.correlation_rules.notification.import.success.sub_title',
      ),
      importFailureTitle: t(
        'correlation_rules:app.correlation_rules.notification.import.failure.title',
      ),
      exportConfirmation: t(
        'correlation_rules:app.correlation_rules.notification.export.confirmation.title',
      ),
      exportPopover: t(
        'correlation_rules:app.correlation_rules.notification.export.popover.title',
      ),
      exportSuccessTitle: t(
        'correlation_rules:app.correlation_rules.notification.export.success.title',
      ),
      exportSuccessSubtitle: t(
        'correlation_rules:app.correlation_rules.notification.export.success.sub_title',
      ),
      exportFailureTitle: t(
        'correlation_rules:app.correlation_rules.notification.export.failure.title',
      ),
      creationSuccess: t(
        'correlation_rules:app.correlation_rules.notification.create.success.title',
      ),
      updateSuccess: t(
        'correlation_rules:app.correlation_rules.notification.update.success.title',
      ),
      deletionSuccess: t(
        'correlation_rules:app.correlation_rules.notification.delete.success.title',
      ),
      creationError: t(
        'correlation_rules:app.correlation_rules.notification.create.failure.title',
      ),
      updateError: t(
        'correlation_rules:app.correlation_rules.notification.update.failure.title',
      ),
      deletionError: t(
        'correlation_rules:app.correlation_rules.notification.delete.failure.title',
      ),
      delete: t('correlation_rules:app.correlation_rules.delete'),
      edit: t('correlation_rules:app.correlation_rules.edit'),
      newEntity: t('correlation_rules:app.correlation_rules.new_rule'),
    };
  };

export function useCorrelationRulesTemplateMessages(): TUseCorrelationRulesAddMessages {
  const { t } = useTranslation([CORRELATION_RULES_CREATE]);

  return {
    title: t('correlation_rules_create:app.correlation_rules_create.title'),
    enableButton: t(
      'correlation_rules_create:app.correlation_rules_create.enabled_button',
    ),
    disableButton: t(
      'correlation_rules_create:app.correlation_rules_create.disabled_button',
    ),
    save: t(
      'correlation_rules_create:app.correlation_rules_create.save_button',
    ),
    formValidationMessages: {
      emptyField: t(
        'correlation_rules_create:app.correlation_rules_create.form_validation_messages.empty_field',
      ),
    },
    basicRuleSettingsMessage: {
      title: t(
        'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.title',
      ),
      ruleName: {
        title: t(
          'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.rule_name.title',
        ),
        placeholder: t(
          'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.rule_name.placeholder',
        ),
      },
      ruleGroup: {
        title: t(
          'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.rule_group.title',
        ),
        placeholder: t(
          'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.rule_group.placeholder',
        ),
      },
      depthAnalysis: {
        title: t(
          'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.depth_analysis.title',
        ),
        placeholder: t(
          'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.depth_analysis.placeholder',
        ),
      },
      sid: {
        title: t(
          'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.sid.title',
        ),
        placeholder: t(
          'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.sid.placeholder',
        ),
      },
      description: {
        title: t(
          'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.description.title',
        ),
        placeholder: t(
          'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.description.placeholder',
        ),
      },
      status: {
        title: t(
          'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.status.title',
        ),
        placeholder: t(
          'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.status.placeholder',
        ),
      },
      multi: {
        title: t(
          'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.multi.title',
        ),
        placeholder: t(
          'correlation_rules_create:app.correlation_rules_create.basic_rule_settings.multi.placeholder',
        ),
      },
    },
    conditionRuleMessage: {
      headerTitle: t(
        'correlation_rules_create:app.correlation_rules_create.condition_rule.header.title',
      ),
      title: t(
        'correlation_rules_create:app.correlation_rules_create.condition_rule.title',
      ),
      checkButton: t(
        'correlation_rules_create:app.correlation_rules_create.condition_rule.check_button',
      ),

      event: {
        created: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.event.created',
        ),
        id: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.event.id',
        ),
        severity: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.event.severity',
        ),
        category: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.event.category',
        ),
        message: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.event.message',
        ),
        sourceIp: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.event.source_ip',
        ),
        destinationIp: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.event.destination_ip',
        ),
        combinedIp: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.event.combined_ip',
        ),
        showMore: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.event.show_more',
        ),
        showLess: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.event.show_less',
        ),
        foundEvents: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.event.found_events',
        ),
        total: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.event.total',
        ),
        ruleHasBeenModified: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.event.rule_has_been_modified',
        ),
        noEventsFound: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.event.no_events_found',
        ),
      },
      selectOptionMessage: {
        placeholder: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.placeholder',
        ),
        createCustomValuePlaceholder: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.create_custom_value.placeholder',
        ),
        eventFirst: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.event_first',
        ),
        eventLast: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.event_last',
        ),
        eventCount: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.event_count',
        ),
        eventTimestamp: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.event_timestamp',
        ),
        eventSeverity: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.event_severity',
        ),
        eventSrcMsg: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.event_src_msg',
        ),
        eventProtocol: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.event_protocol',
        ),
        deviceVendor: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.device_vendor',
        ),
        deviceProduct: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.device_product',
        ),
        deviceVersion: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.device_version',
        ),
        deviceAction: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.device_action',
        ),
        signId: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.sign_id',
        ),
        signCategory: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.sign_category ',
        ),
        signSubcategory: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.sign_subcategory',
        ),
        signName: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.sign_name',
        ),
        sourceIp: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.source_ip',
        ),
        sourceHost: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.source_host',
        ),
        sourcePort: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.source_port',
        ),
        sourceUser: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.source_user',
        ),
        destinationHost: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.destination_host',
        ),
        destinationIp: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.destination_ip',
        ),
        destinationPort: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.destination_port',
        ),
        destinationUser: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.destination_user',
        ),
        AND: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.AND',
        ),
        OR: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.OR',
        ),
        TO: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.TO',
        ),
        more: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.more',
        ),
        less: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.less',
        ),
        moreEqual: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.more_equal',
        ),
        lessEqual: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.less_equal',
        ),
        colon: t(
          'correlation_rules_create:app.correlation_rules_create.condition_rule.select_options.colon',
        ),
      },
    },
    actionsRuleMessage: {
      title: t(
        'correlation_rules_create:app.correlation_rules_create.actions.title',
      ),
      add: t(
        'correlation_rules_create:app.correlation_rules_create.actions.add',
      ),
      check: t(
        'correlation_rules_create:app.correlation_rules_create.actions.check',
      ),
      unsupported: t(
        'correlation_rules_create:app.correlation_rules_create.actions.unsupported',
      ),
      mustSelectActions: t(
        'correlation_rules_create:app.correlation_rules_create.actions.must_select_actions',
      ),
      deleteConfirm: t(
        'correlation_rules_create:app.correlation_rules_create.actions.deleteConfirm',
      ),
      deleteOk: t(
        'correlation_rules_create:app.correlation_rules_create.actions.deleteOk',
      ),
      deleteCancel: t(
        'correlation_rules_create:app.correlation_rules_create.actions.deleteCancel',
      ),
      deleteAction: t(
        'correlation_rules_create:app.correlation_rules_create.actions.deleteAction',
      ),
      generalSelectMessage: {
        bash: t(
          'correlation_rules_create:app.correlations_rules_create.actions.general_select_block.bash',
        ),
        sysLog: t(
          'correlation_rules_create:app.correlations_rules_create.actions.general_select_block.sys_log',
        ),
        incident: t(
          'correlation_rules_create:app.correlations_rules_create.actions.general_select_block.incident',
        ),
        http: t(
          'correlation_rules_create:app.correlations_rules_create.actions.general_select_block.http',
        ),
        runExecutableFile: t(
          'correlation_rules_create:app.correlations_rules_create.actions.general_select_block.run_executable_file',
        ),
        newAssets: t(
          'correlation_rules_create:app.correlations_rules_create.actions.general_select_block.new_assets',
        ),
        fireWall: t(
          'correlation_rules_create:app.correlations_rules_create.actions.general_select_block.firewall',
        ),
      },
      blockMessages: {
        bashMessage: {
          body: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.bash_block.body.title',
            ),
            placeholder: `#!/bin/bash
         
          
${t(
  'correlation_rules_create:app.correlations_rules_create.actions.bash_block.body.placeholder',
)}`,
          },
        },
        syslogMessage: {
          host: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.syslog_block.host.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.syslog_block.host.placeholder',
            ),
          },
          port: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.syslog_block.port.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.syslog_block.port.placeholder',
            ),
          },
          protocol: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.syslog_block.protocol.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.syslog_block.protocol.placeholder',
            ),
          },
          name: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.syslog_block.name.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.syslog_block.name.placeholder',
            ),
          },
          template: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.syslog_block.template.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.syslog_block.template.placeholder',
            ),
          },
        },
        incidentMessage: {
          title: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.placeholder',
            ),
          },
          category: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.category.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.category.placeholder',
            ),
          },
          importance: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.importance.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.importance.placeholder',
            ),
          },
          assignedTo: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.assigned.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.assigned.placeholder',
            ),
          },
          description: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.description.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.description.placeholder',
            ),
          },
          comment: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.comment.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.comment.placeholder',
            ),
          },
          recommendations: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.resolve_recommendations.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.resolve_recommendations.placeholder',
            ),
          },
          effects: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.effects.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.incident_block.effects.placeholder',
            ),
          },
        },
        newAssetsMessage: {
          name: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.placeholder',
            ),
          },
          assetType: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.asset_type.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.asset_type.placeholder',
            ),
          },
          assetTypeValue: {
            user: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.asset_type_value.user',
            ),
            arma_industrial_firewall: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.asset_type_value.arma_industrial_firewall',
            ),
            plc: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.asset_type_value.plc',
            ),
            pc: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.asset_type_value.pc',
            ),
            server: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.asset_type_value.server',
            ),
            network_device: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.asset_type_value.network_device',
            ),
          },
          group: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.group.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.group.placeholder',
            ),
          },
          description: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.description.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.description.placeholder',
            ),
          },
          manufacturer: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.manufacturer.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.manufacturer.placeholder',
            ),
          },
          model: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.model.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.model.placeholder',
            ),
          },
          os: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.os.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.os.placeholder',
            ),
          },
          ip: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.ip.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.ip.placeholder',
            ),
          },
          ports: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.ports.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.ports.placeholder',
            ),
          },
          vulnerabilities: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.vulnerabilities.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.new_assets_block.vulnerabilities.placeholder',
            ),
          },
        },
        runExecutableFileMessage: {
          executablePath: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.run_executable_file_block.executable_path.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.run_executable_file_block.executable_path.placeholder',
            ),
          },
          arguments: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.run_executable_file_block.arguments.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.run_executable_file_block.arguments.placeholder',
            ),
          },
          environment: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.run_executable_file_block.environment.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.run_executable_file_block.environment.placeholder',
            ),
          },
          workingDirectory: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.run_executable_file_block.working_directory.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.run_executable_file_block.working_directory.placeholder',
            ),
          },
        },
        httpMessage: {
          url: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.http_block.url.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.http_block.url.placeholder',
            ),
          },
          contentType: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.http_block.content_type.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.http_block.content_type.placeholder',
            ),
          },
          template: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.http_block.template.title',
            ),
            placeholder: t(
              'correlation_rules_create:app.correlations_rules_create.actions.http_block.template.placeholder',
            ),
          },
        },
        fireWallMessage: {
          armaif: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.armaif.title',
            ),
          },
          enabled: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.enabled.title',
            ),
            extra: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.enabled.extra',
            ),
          },
          quick: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.quick.title',
            ),
          },
          log: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.log.title',
            ),
            extra: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.log.extra',
            ),
          },
          interface: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.interface.title',
            ),
            extra: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.interface.extra',
            ),
          },
          direction: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.direction.title',
            ),
            extra: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.direction.extra',
            ),
          },
          sequence: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.sequence.title',
            ),
            extra: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.sequence.extra',
            ),
          },
          action: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.action.title',
            ),
            extra: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.action.extra',
            ),
          },
          ipprotocol: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.ipprotocol.title',
            ),
          },
          protocol: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.protocol.title',
            ),
          },
          source_net: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.source_net.title',
            ),
          },
          source_port: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.source_port.title',
            ),
          },
          source_not: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.source_not.title',
            ),
          },
          destination_net: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.destination_net.title',
            ),
          },
          destination_port: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.destination_port.title',
            ),
          },
          destination_not: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.destination_not.title',
            ),
          },
          description: {
            title: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.description.title',
            ),
            extra: (limit: number) =>
              t(
                'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.description.extra',
                { limit },
              ),
          },
          other: {
            firewallShouldBeOnline: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.other.firewallShouldBeOnline',
            ),
            firewallIsOnline: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.other.firewallIsOnline',
            ),
            firewallIsOffline: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.other.firewallIsOffline',
            ),
            connectingToTheFirewall: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.other.connectingToTheFirewall',
            ),
            pleaseSelectFirewall: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.other.pleaseSelectFirewall',
            ),
            firewallConnectionError: t(
              'correlation_rules_create:app.correlations_rules_create.actions.firewall_block.other.firewallConnectionError',
            ),
          },
        },
      },
    },
  };
}
