import {
  COMMON,
  DEVICES_DASHBOARD,
  ROTATION_DASHBOARD,
  useTranslation,
} from 'core/i18n';
import {
  EndpointGroupName,
  FirewallGroupName,
  TUseDevicesMessages,
} from 'pages/DevicesDashboard';

export const useDevicesMessages = (): TUseDevicesMessages => {
  const { t } = useTranslation([DEVICES_DASHBOARD, COMMON, ROTATION_DASHBOARD]);

  return {
    title: t('devices_dashboard:app.devices_dashboard.title'),
    leftSideBar: {
      title: t('devices_dashboard:app.devices_dashboard.leftSideBar.title'),
      eventSources: t(
        'devices_dashboard:app.devices_dashboard.leftSideBar.event_sources',
      ),
      tags: t('devices_dashboard:app.devices_dashboard.leftSideBar.tags'),
    },
    table: {
      columnMessages: {
        id: t('devices_dashboard:app.devices_dashboard.table.column.id'),
        status: t(
          'devices_dashboard:app.devices_dashboard.table.column.status',
        ),
        name: t('devices_dashboard:app.devices_dashboard.table.column.name'),
        type: t('devices_dashboard:app.devices_dashboard.table.column.type'),
        ip: t('devices_dashboard:app.devices_dashboard.table.column.ip'),
        decisiveRuleVersion: t(
          'devices_dashboard:app.devices_dashboard.table.column.decisive_rule_version',
        ),
        groups: t(
          'devices_dashboard:app.devices_dashboard.table.column.groups',
        ),
        port: t('devices_dashboard:app.devices_dashboard.table.column.port'),
        info: t('devices_dashboard:app.devices_dashboard.table.column.info'),
        update: t(
          'devices_dashboard:app.devices_dashboard.table.column.update',
        ),
        actions: t(
          'devices_dashboard:app.devices_dashboard.table.column.actions',
        ),
      },
      button: {
        addDevice: t(
          'devices_dashboard:app.devices_dashboard.table.button.add_device',
        ),
        addGroup: t(
          'devices_dashboard:app.devices_dashboard.table.button.add_group',
        ),
      },
    },
    notification: {
      newDevicesConnected: t(
        'devices_dashboard:app.devices_dashboard.notification.new_device_connected',
      ),
      deviceChanged: t(
        'devices_dashboard:app.devices_dashboard.notification.device_changed',
      ),
      deviceDeleted: t(
        'devices_dashboard:app.devices_dashboard.notification.devices_deleted',
      ),
      deviceDeletedQuestion: t(
        'devices_dashboard:app.devices_dashboard.notification.devices_deleted_question',
      ),
      saved: t('devices_dashboard:app.devices_dashboard.notification.saved'),
      uploaded: t(
        'devices_dashboard:app.devices_dashboard.notification.uploaded',
      ),
      uploadedError: t(
        'devices_dashboard:app.devices_dashboard.notification.uploaded_error',
      ),
      uploadedErrorDescription: t(
        'devices_dashboard:app.devices_dashboard.notification.uploaded_error_description',
      ),
      successSavedConfiguration: t(
        'devices_dashboard:app.devices_dashboard.notification.success_saved_configuration',
      ),
      failedSavedConfiguration: t(
        'devices_dashboard:app.devices_dashboard.notification.failed_saved_configuration',
      ),
      uploadedConfiguration: t(
        'devices_dashboard:app.devices_dashboard.notification.uploaded_configuration',
      ),
      uploadedRules: t(
        'devices_dashboard:app.devices_dashboard.notification.uploaded_rules',
      ),
      uploadedRulesNotFullRules: (count: number, total: number): string =>
        t(
          'devices_dashboard:app.devices_dashboard.notification.uploaded_rules_not_full_rules',
          { count, total },
        ),
      preUploadedRules: t(
        'devices_dashboard:app.devices_dashboard.notification.pre_uploaded_rules',
      ),
      updated: t(
        'devices_dashboard:app.devices_dashboard.notification.updated',
      ),
      updatedConfiguration: t(
        'devices_dashboard:app.devices_dashboard.notification.updated_configuration',
      ),
      updatedError: t(
        'devices_dashboard:app.devices_dashboard.notification.updated_error',
      ),
      updatedErrorDescription: t(
        'devices_dashboard:app.devices_dashboard.notification.updated_error_description',
      ),
      updatedClamAVDBSuccess: t(
        'devices_dashboard:app.devices_dashboard.notification.collective_action.updated_clam_av_db_success.title',
      ),
      updatedClamAVDBWarningFileExistTitle: t(
        'devices_dashboard:app.devices_dashboard.notification.collective_action.updated_clam_av_db_warning_file_exist.title',
      ),
      updatedClamAVDBWarningFileExistSubTitle: t(
        'devices_dashboard:app.devices_dashboard.notification.collective_action.updated_clam_av_db_warning_file_exist.sub_title',
      ),
      tryLater: t(
        'devices_dashboard:app.devices_dashboard.notification.try_later',
      ),
      groupSuccessDelete: t(
        'devices_dashboard:app.devices_dashboard.notification.success.delete.group.title',
      ),
      groupFailedDelete: t(
        'devices_dashboard:app.devices_dashboard.notification.error.delete.group.title',
      ),
      firewallFailConnect: t(
        'devices_dashboard:app.devices_dashboard.notification.error.post.firewall.title',
      ),
      firewallFailChangeConfiguration: t(
        'devices_dashboard:app.devices_dashboard.notification.error.patch.firewall.title',
      ),
      endpointFailChangeConfiguration: t(
        'devices_dashboard:app.devices_dashboard.notification.error.patch.endpoint.title',
      ),
      sensorFailedCreate: t(
        'devices_dashboard:app.devices_dashboard.notification.error.create.sensor.title',
      ),
      sensorFailChangeConfiguration: t(
        'devices_dashboard:app.devices_dashboard.notification.error.patch.sensor.title',
      ),
      tryAgain: t(
        'devices_dashboard:app.devices_dashboard.notification.try_again',
      ),
      firewallReboot: {
        success: t(
          'devices_dashboard:app.devices_dashboard.notification.firewall.reboot.success',
        ),
        failed: t(
          'devices_dashboard:app.devices_dashboard.notification.action_not_complete',
        ),
      },
      failedFetchEventSourceData: t(
        'devices_dashboard:app.devices_dashboard.notification.failed_fetch_event_source_data',
      ),
    },
    localeCardInfo: {
      title: t('devices_dashboard:app.devices_dashboard.card_info.title'),
      copyEndpointTitle: t(
        'devices_dashboard:app.devices_dashboard.card_info.copy_title',
      ),
      typeSelector: {
        placeholder: t(
          'devices_dashboard:app.devices_dashboard.table.card_info.type_selector.placeholder',
        ),
        validation: t(
          'devices_dashboard:app.devices_dashboard.table.card_info.type_selector.validation',
        ),
      },
      type: t('devices_dashboard:app.devices_dashboard.table.column.type'),
      endpoint: {
        [EndpointGroupName.Main]: {
          title: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.title',
          ),
          name: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.name.title',
          ),
          namePlaceholder: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.name.placeholder',
          ),
          nameExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.name.extra',
          ),
          ip: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.ip.title',
          ),
          ipPlaceholder: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.ip.placeholder',
          ),
          ipExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.ip.extra',
          ),
          port: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.port.title',
          ),
          portPlaceholder: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.port.placeholder',
          ),
          portExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.port.extra',
          ),
          manufacturer: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.endpoint.manufacturer',
          ),
          group: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.group.title',
          ),
          groupExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.group.extra',
          ),
          info: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.description.title',
          ),
        },
        [EndpointGroupName.Scan]: {
          title: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.scan.title',
          ),
          icEnabled: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.scan.ic_enabled',
          ),
          icTimeout: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.scan.ic_timeout',
          ),
          icTimeoutExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.scan.ic_timeout_extra',
          ),
          table: {
            search: t(
              'devices_dashboard:app.devices_dashboard.card_info.endpoint.scan.table.search',
            ),
            searchPlaceholder: t(
              'devices_dashboard:app.devices_dashboard.card_info.endpoint.scan.table.search_placeholder',
            ),
            selectAll: t(
              'devices_dashboard:app.devices_dashboard.card_info.endpoint.scan.table.select_all',
            ),
            columns: {
              ic_scan_folders: t(
                'devices_dashboard:app.devices_dashboard.card_info.endpoint.scan.table.columns.file_or_folder_path',
              ),
              actions: t(
                'devices_dashboard:app.devices_dashboard.card_info.endpoint.scan.table.columns.actions',
              ),
            },
          },
        },
        [EndpointGroupName.WhiteList]: {
          title: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.wl.title',
          ),
          wlEnable: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.wl.wl_enable',
          ),
          wlAdmin: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.wl.wl_admin',
          ),
          table: {
            search: t(
              'devices_dashboard:app.devices_dashboard.card_info.endpoint.wl.table.search',
            ),
            selectAll: t(
              'devices_dashboard:app.devices_dashboard.card_info.endpoint.wl.table.select_all',
            ),
            columns: {
              whiteList: t(
                'devices_dashboard:app.devices_dashboard.card_info.endpoint.wl.table.columns.path_to_folder_or_file',
              ),
              actions: t(
                'devices_dashboard:app.devices_dashboard.card_info.endpoint.wl.table.columns.actions',
              ),
            },
          },
        },
        [EndpointGroupName.Device]: {
          title: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.title',
          ),

          dcEnabled: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.dc_enabled',
          ),
          prohibitCdAccess: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.prohibit_cd_access',
          ),
          prohibitCdAccessExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.prohibit_cd_access_extra',
          ),
          usbControlEnabled: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.usb_control_enabled',
          ),
          usbControlEnabledExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.usb_control_enabled_extra',
          ),
          table: {
            search: t(
              'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.table.search',
            ),
            selectColumns: t(
              'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.table.select_all',
            ),
            manageDeviceClassAccess: t(
              'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.table.manage_device_class_access',
            ),
            columns: {
              name: t(
                'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.table.columns.name',
              ),
              deviceClass: t(
                'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.table.columns.device_class',
              ),
              deviceSubClass: t(
                'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.table.columns.device_sub_class',
              ),
              sn: t(
                'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.table.columns.serial_number',
              ),
              connected: t(
                'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.table.columns.connected',
              ),
              controlStatus: t(
                'devices_dashboard:app.devices_dashboard.card_info.endpoint.device.table.columns.control_status',
              ),
            },
          },
        },
        [EndpointGroupName.Antivirus]: {
          title: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.settings.title',
          ),
          scanBlockTitle: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.scan_block.title',
          ),
          clamavEnabled: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.enabled',
          ),
          clamavStartScan: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.start_scan',
          ),
          clamavStartScanExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.start_scan_extra',
          ),
          clamavResults: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.scan_results',
          ),
          clamavResultsExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.scan_results_extra',
          ),
          clamavDeleteInfectedFiles: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.delete_infected_files',
          ),
          clamavUpdateDb: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.update_db',
          ),
          loadUpdateFiles: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.load_update_files',
          ),
          viewLog: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.view_log',
          ),
          table: {
            search: t(
              'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.table.search',
            ),
            selectAll: t(
              'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.table.select_all',
            ),
            columns: {
              clamav_paths: t(
                'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.table.columns.path_to_folder_or_file',
              ),
              actions: t(
                'devices_dashboard:app.devices_dashboard.card_info.endpoint.antivirus.table.columns.actions',
              ),
            },
          },
        },
        [EndpointGroupName.Rotation]: {
          title: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.rotation.title',
          ),
          period: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.rotation.period',
          ),
          day: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.rotation.day',
          ),
          week: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.rotation.week',
          ),
          month: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.rotation.month',
          ),
          time: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.rotation.time',
          ),
          periodExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.rotation.period_extra',
          ),
          timeExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.endpoint.rotation.time_extra',
          ),
        },
        dynamicTable: {
          selectAll: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.select_all',
          ),
          unSelectAll: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.un_select_all',
          ),
          searchPlaceholder: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.search_placeholder',
          ),
          pathToFile: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.path_to_file',
          ),
          edit: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.edit',
          ),
          delete: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.delete',
          ),
          save: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.save',
          ),
          cancel: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.cancel',
          ),
          selectedEntries: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.selected_entries',
          ),
          deleteQuestions: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.delete_questions',
          ),
          deleteEditQuestions: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.delete_edit_questions',
          ),
          cancelQuestions: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.cancel_questions',
          ),
          deleteMasQuestions: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.delete_mas_questions',
          ),
          ok: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.ok',
          ),
          actions: t(
            'devices_dashboard:app.devices_dashboard.card_info.dynamic_table.actions',
          ),
          validation: {
            thisPathExist: t(
              'devices_dashboard:app.devices_dashboard.card_info.validation.path_exist',
            ),
          },
        },
      },
      firewall: {
        [FirewallGroupName.Main]: {
          title: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.title',
          ),
          name: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.name',
          ),
          namePlaceholder: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.name_placeholder',
          ),
          nameExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.name_extra',
          ),
          ip: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.ip',
          ),
          ipPlaceholder: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.ip_placeholder',
          ),
          ipExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.ip_extra',
          ),
          key: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.key',
          ),
          keyPlaceholder: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.key_placeholder',
          ),
          keyExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.key_extra',
          ),
          secret: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.secret',
          ),
          secretPlaceholder: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.secret_placeholder',
          ),
          secretExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.secret_extra',
          ),
          port: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.port',
          ),
          portPlaceholder: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.port_placeholder',
          ),
          portExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.port_extra',
          ),
          group: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.group',
          ),
          groupExtra: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.group_extra',
          ),
          info: t(
            'devices_dashboard:app.devices_dashboard.card_info.firewall.main.info',
          ),
        },
      },
      sensor: {
        main: {
          title: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.title',
          ),
          name: {
            title: t(
              'devices_dashboard:app.devices_dashboard.card_info.main.name.title',
            ),
            placeholder: t(
              'devices_dashboard:app.devices_dashboard.card_info.main.name.placeholder',
            ),
            extra: t(
              'devices_dashboard:app.devices_dashboard.card_info.main.name.extra',
            ),
          },
          ip: {
            title: t(
              'devices_dashboard:app.devices_dashboard.card_info.main.ip.title',
            ),
            placeholder: t(
              'devices_dashboard:app.devices_dashboard.card_info.main.ip.placeholder',
            ),
            extra: t(
              'devices_dashboard:app.devices_dashboard.card_info.main.ip.extra',
            ),
          },
          port: {
            title: t(
              'devices_dashboard:app.devices_dashboard.card_info.main.port.title',
            ),
            placeholder: t(
              'devices_dashboard:app.devices_dashboard.card_info.main.name.placeholder',
            ),
            extra: t(
              'devices_dashboard:app.devices_dashboard.card_info.main.port.extra',
            ),
          },
          group: {
            title: t(
              'devices_dashboard:app.devices_dashboard.card_info.main.group.title',
            ),
            extra: t(
              'devices_dashboard:app.devices_dashboard.card_info.main.group.extra',
            ),
          },
          description: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.description.title',
          ),
          authenticationKey: {
            title: t(
              'devices_dashboard:app.devices_dashboard.card_info.main.sensor.authentication_key.title',
            ),
            help: {
              emptyField: t(
                'devices_dashboard:app.devices_dashboard.card_info.main.sensor.authentication_key.help.empty_field',
              ),
              fullField: t(
                'devices_dashboard:app.devices_dashboard.card_info.main.sensor.authentication_key.help.full_field',
              ),
            },
          },
        },
        interfaceFields: {
          title: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.sensor.interfaces.title',
          ),
          name: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.sensor.interfaces.name',
          ),
          extra: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.sensor.interfaces.extra',
          ),
        },
        networkTrafficAnalyzers: {
          title: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.sensor.network_traffic_analyzers.title',
          ),
          enableSignatureAnalysis: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.sensor.network_traffic_analyzers.enable_signature_analysis',
          ),
          enableDpiProtocolAnalysis: t(
            'devices_dashboard:app.devices_dashboard.card_info.main.sensor.network_traffic_analyzers.enable_dpi_protocol_analysis',
          ),
        },
        notification: {
          copyAuthorizationKeySuccess: t(
            'devices_dashboard:app.devices_dashboard.notification.success.sensor.copy_authorization_key',
          ),
        },
      },
      formFieldValidation: {
        fieldExist: (field: string) =>
          t(
            'devices_dashboard:app.devices_dashboard.card_info.validation.item_exist',
            {
              field,
            },
          ),
      },
    },
    singleActionMessages: {
      downloadFireWallConfig: t(
        'devices_dashboard:app.devices_dashboard.single_actions.firewall.download_config',
      ),
      uploadFireWallConfig: t(
        'devices_dashboard:app.devices_dashboard.single_actions.firewall.upload_config',
      ),
      uploadFireWallRules: t(
        'devices_dashboard:app.devices_dashboard.single_actions.firewall.upload_rules',
      ),
      downloadEndpointConfig: t(
        'devices_dashboard:app.devices_dashboard.single_actions.endpoint.download_config',
      ),
      updateEndpointConfig: t(
        'devices_dashboard:app.devices_dashboard.single_actions.endpoint.update_config',
      ),
      firewallReboot: t(
        'devices_dashboard:app.devices_dashboard.single_actions.firewall.reboot',
      ),
      deleting: {
        popover: t('common:app.common.single_actions.delete.popover_title'),
        confirm: t('common:app.common.single_actions.delete.title'),
      },
      edit: t('common:app.common.single_actions.edit'),
    },
    collectiveActionsMessages: {
      updateClamAVDB: {
        popoverMessage: t(
          'devices_dashboard:app.devices_dashboard.card_info.firewall.collective_actions.upload_clam_av_db.popover_title',
        ),
        confirmMessage: t(
          'devices_dashboard:app.devices_dashboard.card_info.firewall.collective_actions.upload_clam_av_db.confirm_title',
        ),
      },
      downloadFireWallConfig: {
        popoverMessage: t(
          'devices_dashboard:app.devices_dashboard.card_info.firewall.collective_actions.download_config.popover_title',
        ),
        confirmMessage: t(
          'devices_dashboard:app.devices_dashboard.card_info.firewall.collective_actions.download_config.confirm_title',
        ),
      },
      uploadFireWallConfig: {
        popoverMessage: t(
          'devices_dashboard:app.devices_dashboard.card_info.firewall.collective_actions.upload_config.popover_title',
        ),
        confirmMessage: t(
          'devices_dashboard:app.devices_dashboard.card_info.firewall.collective_actions.upload_config.confirm_title',
        ),
      },
      uploadFireWallRules: {
        popoverMessage: t(
          'devices_dashboard:app.devices_dashboard.card_info.firewall.collective_actions.upload_rules.popover_title',
        ),
        confirmMessage: t(
          'devices_dashboard:app.devices_dashboard.card_info.firewall.collective_actions.upload_rules.confirm_title',
        ),
        notification: {
          warning: t(
            'devices_dashboard:app.devices_dashboard.notification.collective_action.update_ids_rules.warning.title',
          ),
          success: t(
            'devices_dashboard:app.devices_dashboard.notification.collective_action.update_ids_rules.success.title',
          ),
        },
      },
      updateEndpointConfig: {
        popoverMessage: t(
          'devices_dashboard:app.devices_dashboard.card_info.endpoint.collective_actions.update_config.popover_title',
        ),
        confirmMessage: t(
          'devices_dashboard:app.devices_dashboard.card_info.endpoint.collective_actions.update_config.confirm_title',
        ),
      },
      successMessages: t(
        'devices_dashboard:app.devices_dashboard.notification.collective_action.success.title',
      ),
      warningMessage: t(
        'devices_dashboard:app.devices_dashboard.notification.collective_action.warning.title',
      ),
      errorMessage: t(
        'devices_dashboard:app.devices_dashboard.notification.collective_action.error.title',
      ),
      descriptionErrorAndWarningMessage: t(
        'devices_dashboard:app.devices_dashboard.notification.collective_action.error_warning.description',
      ),
    },
  };
};
